==> jc-1.4.0.tar.gz: soot/javaToJimple/ClassToSourceBuilder.h <==
// public class soot.javaToJimple.ClassToSourceBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class f087c25aa84a471a soot_javaToJimple_ClassToSourceBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ClassToSourceBuilder_H_
#define _JC_soot_javaToJimple_ClassToSourceBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs	_jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs	_jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$refs	_jc_soot_javaToJimple_ClassToSourceBuilder$refs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs	_jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$object	_jc_soot_javaToJimple_ClassToSourceBuilder$object;

typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vmethods	_jc_soot_javaToJimple_ClassToSourceBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtable	_jc_soot_javaToJimple_ClassToSourceBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtype	_jc_soot_javaToJimple_ClassToSourceBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassToSourceBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$fixInnerClassName$dccf481b2cbdf1d5(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *);
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$getAnonMap$0af7fc40aa64a433(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *);
extern struct _jc_object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$fixInnerClassName$dccf481b2cbdf1d5;
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$getAnonMap$0af7fc40aa64a433;
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vmethods {
	struct _jc_java_lang_String$object	*(*fixInnerClassName$dccf481b2cbdf1d5)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *);
	struct _jc_java_util_HashMap$object	*(*getAnonMap$0af7fc40aa64a433)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vmethods	soot_javaToJimple_ClassToSourceBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs {
	struct _jc_object	*list;
	struct _jc_java_util_HashMap$object	*anonMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$refs {
    _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs	soot_javaToJimple_ClassToSourceBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs	soot_javaToJimple_ClassToSourceBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassToSourceBuilder$object {
	_jc_soot_javaToJimple_ClassToSourceBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassToSourceBuilder$vtype _jc_soot_javaToJimple_ClassToSourceBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassToSourceBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassToSourceBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_ClassToSourceBuilder_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/ClassToSourceBuilder.h <==
// public class soot.javaToJimple.ClassToSourceBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class f087c25aa84a471a soot_javaToJimple_ClassToSourceBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ClassToSourceBuilder_H_
#define _JC_soot_javaToJimple_ClassToSourceBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs	_jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs	_jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$refs	_jc_soot_javaToJimple_ClassToSourceBuilder$refs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs	_jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassToSourceBuilder$object	_jc_soot_javaToJimple_ClassToSourceBuilder$object;

typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vmethods	_jc_soot_javaToJimple_ClassToSourceBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtable	_jc_soot_javaToJimple_ClassToSourceBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtype	_jc_soot_javaToJimple_ClassToSourceBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassToSourceBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$fixInnerClassName$dccf481b2cbdf1d5(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_HashMap$object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$getAnonMap$0af7fc40aa64a433(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_ClassToSourceBuilder$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$fixInnerClassName$dccf481b2cbdf1d5;
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$getAnonMap$0af7fc40aa64a433;
extern _jc_method _jc_soot_javaToJimple_ClassToSourceBuilder$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vmethods {
	struct _jc_java_lang_String$object	*(*fixInnerClassName$dccf481b2cbdf1d5)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_util_HashMap$object	*(*getAnonMap$0af7fc40aa64a433)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ClassToSourceBuilder$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vmethods	soot_javaToJimple_ClassToSourceBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_ClassToSourceBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs {
	struct _jc_object	*list;
	struct _jc_java_util_HashMap$object	*anonMap;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$refs {
    _jc_soot_javaToJimple_ClassToSourceBuilder$sub_refs	soot_javaToJimple_ClassToSourceBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ClassToSourceBuilder$sub_nonrefs	soot_javaToJimple_ClassToSourceBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassToSourceBuilder$object {
	_jc_soot_javaToJimple_ClassToSourceBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassToSourceBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_ClassToSourceBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassToSourceBuilder$vtype _jc_soot_javaToJimple_ClassToSourceBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassToSourceBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassToSourceBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_ClassToSourceBuilder_H_ */
